PROGRAM_NAME='CANON, LV-7500U VIDEO PROJECTOR, RS232, 07-13-99, MJR'
(*   DATE:07/23/99    TIME:15:58:39    *)
(***********************************************************)
(* The following code block is provided as a guide to      *)
(* programming the device(s) listed above. This is a       *)
(* sample only, and will most likely require modification  *)
(* to be integrated into a master program.                 *)
(*                                                         *)
(* Device-specific protocols should be obtained directly   *)
(* from the equipment manufacturer to ensure compliance    *)
(* with the most current versions. Within the limits       *)
(* imposed by any non-disclosure agreements, AMX will      *)
(* provide protocols upon request.                         *)
(*                                                         *)
(* If further programming assistance is required, please   *)
(* contact your AMX customer support team.                 *)
(*                                                         *)

(***********************************************************)
(* GENERAL FUNCTION LIST -                                 *)
(* POWER      -  ON/OFF                                    *)
(* VID MUTE   -  ON/OFF (!!USE MOMENTARY FB!!)             *)
(* INPUTS     -  VID1, PC1, PC2                            *)
(* ZOOM, FOCUS, FREEZE                                     *)
(* CURSOR CONTROL, MENU ON/OFF, ENTER                      *)
(* MISC: DISPLAY CLEAR, NORMAL, AUTO IMAGE, P-TMR          *)

(***********************************************************)
(* FIND.NOTES *)
(* NOTES:                                                  *)
(*   -  SEARCH FOR FIND.NOTES FOR IMPORTANT PROGRAMMING    *)
(*      NOTES.                                             *)

(***********************************************************)
(* FIND.NOTES *)
(* NOTES: - THE INTERCONNECTING CABLE MUST BE CONNECTED TO *)
(*          THE CONTROL PORT 2, NOT CONTROL PORT 1         *)

(***********************************************************)
(* System Type :  AXCENT 2                                 *)
(***********************************************************)

(***********************************************************)
(*          DEVICE NUMBER DEFINITIONS GO BELOW             *)
(***********************************************************)
DEFINE_DEVICE

VPROJ   =  1     (* CANON LV-7500U 192/8/N/1 *)
                 (* FG10-752-01 *)
TP      =  192   (* AXT-MCA/MCV *)

(***********************************************************)
(*               CONSTANT DEFINITIONS GO BELOW             *)
(***********************************************************)
DEFINE_CONSTANT

(*** CANON LV-7500U (CHANNELS USED) ***)
VP_PWR        =  9     (* POWER STATE                                     *)
VP_ON_DELAY   = 10     (* DELAY AFTER THE 'ON' CMD IS ISSUED              *)
VP_OFF_DELAY  = 11     (* DELAY AFTER THE 'OFF' CMD IS ISSUED             *)

VP_VID_MUTE   =  20    (* VIDEO MUTE FLAG                                 *)

VP_VOL_UP     =  24    (* VOLUME                                          *)
VP_VOL_DN     =  25
VP_VOL_MUTE   =  26

VP_VID1       =  51    (* INPUTS SELECTED                                 *)
VP_PC1        =  53
VP_PC2        =  54

VP_ZOOM_IN    =  61    (* ZOOM                                            *)
VP_ZOOM_OUT   =  62

VP_FOCUS_NEAR =  63    (* FOCUS                                           *)
VP_FOCUS_FAR  =  64

VP_LENS_UP    =  65    (* LENS SHIFT                                      *)
VP_LENS_DN    =  66

VP_MENU       =  67
VP_FREEZE     =  68

VP_CURSOR_UP  =  71    (* CURSOR CONTROL                                  *)
VP_CURSOR_DN  =  72
VP_CURSOR_LT  =  73
VP_CURSOR_RT  =  74

VP_ON         =  27    (* FUNCTIONS *)
VP_OFF        =  28

VP_NO_SHOW    =  55

VP_BUSY       = 254
(***********************************************************)
(*               VARIABLE DEFINITIONS GO BELOW             *)
(***********************************************************)
DEFINE_VARIABLE

FLASH
ZOOM_COUNTER
FOCUS_COUNTER

DEBUG_VPROJ         (* FLAG TO SEND RESPONSES TO TERMINAL                 *)
VPROJ_BUFF[100]     (* RESPONSES                                          *)
RESPONSE[30]

(***********************************************************)
(*               LATCHING DEFINITIONS GO BELOW             *)
(***********************************************************)
DEFINE_LATCHING

(***********************************************************)
(*       MUTUALLY EXCLUSIVE DEFINITIONS GO BELOW           *)
(***********************************************************)
DEFINE_MUTUALLY_EXCLUSIVE

(***********************************************************)
(*           SUBROUTINE DEFINITIONS GO BELOW               *)
(***********************************************************)

(****************)
(* CANVP00F     *)
(***********************************************************)
(* FUNCTIONS: PWR ON/OFF, VIDEO MUTE, AUDIO MUTE, INPUT    *)
(*  SELECTS (VID1,PC1,PC2), ZOOM, FOCUS                    *)
(***********************************************************)
DEFINE_CALL 'CANVP00F' (FUNC)
{
  SELECT
  {
    ACTIVE (FUNC = VP_ON) :        (* POWER ON *)
    {
      SEND_STRING VPROJ,"'C00',13"
                                   (* FIND.NOTES *)
      IF(![VPROJ,VP_PWR])          (* NOTE: THE FIRST 'ON' CMD ISSUED WILL  *)
      {                            (* TURN THE PROJECTOR ON WITH THE 'CANON'*)
        ON [VPROJ,VP_ON_DELAY]     (* LOGO DISPLAYED WITH A COUNTDOWN TIMER.*)
        WAIT 300 'VP ON DELAY'
          OFF[VPROJ,VP_ON_DELAY]
      }
      ELSE
      {                            (* MOST OTHER CMDS STOP THE CANON POWER  *)
        CANCEL_WAIT 'VP ON DELAY'  (* ON COUNTDOWN TIMER AND REMOVE THE     *)
        OFF[VPROJ,VP_ON_DELAY]     (* 'CANON' LOGO FROM THE DISPLAY!!       *)
      }
      ON [VPROJ,VP_PWR]
      OFF[VPROJ,VP_VID_MUTE]
      OFF[VPROJ,VP_NO_SHOW]
    }
    ACTIVE (FUNC = VP_OFF) :       (* POWER OFF *)
    {
      SEND_STRING VPROJ,"'C01',13"
                                   (* FIND.NOTES *)
      IF([VPROJ,VP_PWR])           (* NOTE: ONCE THE 'OFF' CMD IS ISSUED,   *)
      {                            (*THE CANON IS LOCKED INTO IT'S 60 SECOND*)
        CANCEL_WAIT 'VP ON DELAY'  (* TIMER FOR FAN EXHAUST WITH LAMP OFF.  *)
        OFF[VPROJ,VP_ON_DELAY]     (* ONCE HERE, YOU MUST WAIT TO TURN IT   *)
                                   (* BACK ON!                              *)
        ON [VPROJ,VP_OFF_DELAY]
        WAIT 600 'VP OFF DELAY'
          OFF[VPROJ,VP_OFF_DELAY]
      }
      OFF[VPROJ,VP_PWR]
      OFF[VPROJ,VP_VID_MUTE]
      OFF[VPROJ,VP_NO_SHOW]
    }
(* FIND.NOTES *)
(* NOTE: - SLECTING AN INPUT DURING POWER UP OTHER THAN THE INPUT SELECTED  *)
(*       - WHEN THE PROJECTOR WAS TURNED OFF WILL MAKE THE LOGO SCREEN AND  *)
(*       - TIMER DISAPPEAR. ALSO, WHEN IN VIDEO MUTE OR NO SHOW, SELECTING  *)
(*       - THE CURRENT INPUT AGAIN DOES NOT TURN OFF THESE MUTE MODES       *)

    ACTIVE (FUNC = VP_VID1) :      (* INPUT = VID1 *)
    IF (![VPROJ,VP_BUSY])          
    {                              
      ON [VPROJ,VP_BUSY]
      WAIT 5 OFF [VPROJ,VP_BUSY]   
      SEND_STRING VPROJ,"'C07',13" 
    (* INPUT SELECT *)
      IF (![VPROJ,VP_VID1])
      {
         CANCEL_WAIT 'VP ON DELAY'
         OFF[VPROJ,VP_ON_DELAY]
         OFF[VPROJ,VP_VID_MUTE]
         OFF[VPROJ,VP_NO_SHOW]
      }
      OFF[VPROJ,VP_PC1]
      OFF[VPROJ,VP_PC2]
      ON [VPROJ,VP_VID1]
    }
    ACTIVE (FUNC = VP_PC1) :       (* INPUT = PC1 *)
    IF (![VPROJ,VP_BUSY])
    {
      ON [VPROJ,VP_BUSY]
      WAIT 5 OFF [VPROJ,VP_BUSY]
      SEND_STRING VPROJ,"'C05',13"
    (* INPUT SELECT *)
      IF (![VPROJ,VP_PC1])
      {
         CANCEL_WAIT 'VP ON DELAY'
         OFF[VPROJ,VP_ON_DELAY]
         OFF[VPROJ,VP_VID_MUTE]
         OFF[VPROJ,VP_NO_SHOW]
      }
      OFF[VPROJ,VP_VID1]
      OFF[VPROJ,VP_PC2]
      ON [VPROJ,VP_PC1]
    }
    ACTIVE (FUNC = VP_PC2) :       (* INPUT = PC2 *)
    IF (![VPROJ,VP_BUSY])
    {
      ON [VPROJ,VP_BUSY]
      WAIT 5 OFF [VPROJ,VP_BUSY]
      SEND_STRING VPROJ,"'C06',13"
    (* INPUT SELECT *)
      IF (![VPROJ,VP_PC2])
      {
         CANCEL_WAIT 'VP ON DELAY'
         OFF[VPROJ,VP_ON_DELAY]
         OFF[VPROJ,VP_VID_MUTE]
         OFF[VPROJ,VP_NO_SHOW]
      }
      OFF[VPROJ,VP_VID1]
      OFF[VPROJ,VP_PC1]
      ON [VPROJ,VP_PC2]
    }
    ACTIVE (FUNC = VP_VID_MUTE) :  (* VIDEO MUTE ON *)
    {
      SEND_STRING VPROJ,"'C0D',13"
      ON [VPROJ,VP_VID_MUTE]
      OFF[VPROJ,VP_NO_SHOW]
      CANCEL_WAIT 'VP ON DELAY'
      OFF[VPROJ,VP_ON_DELAY]
    }
    ACTIVE (FUNC = (VP_VID_MUTE | $100)) : (* VIDEO MUTE OFF *)
    {
      SEND_STRING VPROJ,"'C0E',13"
      OFF[VPROJ,VP_VID_MUTE]
    }
    ACTIVE (FUNC = VP_VOL_MUTE) :  (* AUDIO MUTE ON *)
    {
      SEND_STRING VPROJ,"'C0B',13"
      ON [VPROJ,VP_VOL_MUTE]
      CANCEL_WAIT 'VP ON DELAY'
      OFF[VPROJ,VP_ON_DELAY]
      OFF[VPROJ,VP_VID_MUTE]
      OFF[VPROJ,VP_NO_SHOW]
    }
    ACTIVE (FUNC = (VP_VOL_MUTE | $100)) : (* AUDIO MUTE OFF *)
    {
      SEND_STRING VPROJ,"'C0C',13"
      OFF[VPROJ,VP_VOL_MUTE]
      OFF[VPROJ,VP_NO_SHOW]
      OFF[VPROJ,VP_VID_MUTE]
    }
    ACTIVE (FUNC = VP_ZOOM_IN) :   (* ZOOM TELE *)
    {
      OFF[VPROJ,VP_VID_MUTE]
      OFF[VPROJ,VP_ZOOM_OUT]
      ON [VPROJ,VP_ZOOM_IN]
      SEND_STRING VPROJ,"'C46',13"
      CANCEL_WAIT 'VP ON DELAY'
      OFF[VPROJ,VP_ON_DELAY]
      OFF[VPROJ,VP_VID_MUTE]
      OFF[VPROJ,VP_NO_SHOW]
    }
    ACTIVE (FUNC = VP_ZOOM_OUT) :  (* ZOOM WIDE *)
    {
      OFF[VPROJ,VP_VID_MUTE]
      ON [VPROJ,VP_ZOOM_OUT]
      OFF[VPROJ,VP_ZOOM_IN]
      SEND_STRING VPROJ,"'C47',13"
      CANCEL_WAIT 'VP ON DELAY'
      OFF[VPROJ,VP_ON_DELAY]
      OFF[VPROJ,VP_VID_MUTE]
      OFF[VPROJ,VP_NO_SHOW]
    }
    ACTIVE ((FUNC = (VP_ZOOM_IN  | $100)) ||
            (FUNC = (VP_ZOOM_OUT | $100))) :  (* ZOOM STOP *)
    {
      OFF[VPROJ,VP_VID_MUTE]
      OFF[VPROJ,VP_ZOOM_OUT]
      OFF[VPROJ,VP_ZOOM_IN]
    }
    ACTIVE (FUNC = VP_FOCUS_NEAR) :(* FOCUS NEAR *)
    {
      OFF[VPROJ,VP_VID_MUTE]
      OFF[VPROJ,VP_FOCUS_FAR]
      ON [VPROJ,VP_FOCUS_NEAR]
      SEND_STRING VPROJ,"'C4A',13"
      CANCEL_WAIT 'VP ON DELAY'
      OFF[VPROJ,VP_ON_DELAY]
      OFF[VPROJ,VP_VID_MUTE]
      OFF[VPROJ,VP_NO_SHOW]
    }
    ACTIVE (FUNC = VP_FOCUS_FAR) : (* FOCUS FAR *)
    {
      OFF[VPROJ,VP_VID_MUTE]
      ON [VPROJ,VP_FOCUS_FAR]
      OFF[VPROJ,VP_FOCUS_NEAR]
      SEND_STRING VPROJ,"'C4B',13"
      CANCEL_WAIT 'VP ON DELAY'
      OFF[VPROJ,VP_ON_DELAY]
      OFF[VPROJ,VP_VID_MUTE]
      OFF[VPROJ,VP_NO_SHOW]
    }
    ACTIVE ((FUNC = (VP_FOCUS_FAR  | $100)) ||
            (FUNC = (VP_FOCUS_NEAR | $100))) :(* FOCUS STOP *)
    {
      OFF[VPROJ,VP_VID_MUTE]
      OFF[VPROJ,VP_FOCUS_FAR]
      OFF[VPROJ,VP_FOCUS_NEAR]
    }
  }
}


(***********************************************************)
(*                STARTUP CODE GOES BELOW                  *)
(***********************************************************)
DEFINE_START
SEND_COMMAND VPROJ,"'SET BAUD 19200,8,N,1'"

(*** CANON LV-7500U ***)
DEBUG_VPROJ = 1
CREATE_BUFFER VPROJ,VPROJ_BUFF
VPROJ_BUFF = ""

(***********************************************************)
(*            THE ACTUAL PROGRAM GOES BELOW                *)
(***********************************************************)
DEFINE_PROGRAM

WAIT 10 'FLASH'
  FLASH = !FLASH

(* FIND.NOTES *)
(* NOTE: - ONCE THE POWER OFF CMD IS ISSUED, YOU MUST DELAY BEFORE TURNING  *)
(*         THE UNIT BACK ON!  THE PROJECTOR WILL NOT TURN BACK ON UNTIL     *)
(*         IT HAS FINISHED IT'S COOL DOWN PROCESS (1 MINUTE).               *)
(*       - WHEN THE POWER ON CMD IS ISSUED, THE CANON LOGO IS DISPLAYED WITH*)
(*         A COUNTDOWN TIMER (30 SECONDS).  IF ANOTHER ON CMD OR AN INPUT   *)
(*         SELECT CMD IS ISSUED, THE LOGO DISAPPEARS AND THE INPUT IS       *)
(*         DISPLAYED.  THIS PROGRAM PROVIDES A VP_ON_DELAY CHANNEL FOR FB   *)
(*         BUT IT SHOULD BE CONSIDERED FB ONLY AND NOT A FLAG TO ISSUE      *)
(*         OTHER COMMANDS ON A TIMED BASIS!                                 *)

PUSH[TP,1]                         (* POWER ON *)
{
  IF([VPROJ,VP_OFF_DELAY])
    SEND_COMMAND TP,'ADBEEP'
  ELSE
    CALL 'CANVP00F' (VP_ON)
}

IF ([VPROJ,VP_ON_DELAY])
   [TP,1]  = [VPROJ,VP_PWR] && FLASH
ELSE
   [TP,1] = [VPROJ,VP_PWR]

PUSH[TP,2]                         (* POWER OFF *)
{
  CALL 'CANVP00F' (VP_OFF)
}

IF ([VPROJ,VP_OFF_DELAY])
   [TP,2]  = (![VPROJ,VP_PWR]) && FLASH
ELSE
   [TP,2] = (![VPROJ,VP_PWR])

(* FIND.NOTES *)
(* NOTE:-THIS PROJECTOR WILL ALLOW YOU TO SELECT AN INPUT WHILE THE PROJECOR*)
(*       IS OFF.  WHEN POWER IS TURNED BACK ON, THE LAST SELECTED INPUT WILL*)
(*       BECOME THE NEW SOURCE!!                                            *)
(*      -INPUT SELECTS WILL TURN OFF VIDEO MUTE.                            *)
(*      -INPUT SELECTS WILL NOT TURN PROJECTOR ON.                          *)

PUSH[TP,3]                         (* INPUT = VID1 *)
{
  CALL 'CANVP00F' (VP_VID1)
}
[TP,3] = [VPROJ,VP_VID1] && [VPROJ,VP_PWR]

PUSH[TP,4]                         (* INPUT = PC1 *)
{
  CALL 'CANVP00F' (VP_PC1)
}
[TP,4] = [VPROJ,VP_PC1] && [VPROJ,VP_PWR]

PUSH[TP,5]                         (* INPUT = PC2 *)
{
  CALL 'CANVP00F' (VP_PC2)
}
[TP,5] = [VPROJ,VP_PC2] && [VPROJ,VP_PWR]


PUSH[TP,6]                         (* VIDEO MUTE ***)
{
  TO [TP,6]
  IF(![VPROJ,VP_VID_MUTE])
    CALL 'CANVP00F' (VP_VID_MUTE)          (* VIDEO MUTE ON *)
  ELSE
    CALL 'CANVP00F' (VP_VID_MUTE | $100)   (* VIDEO MUTE OFF *)
}
(* MOMENTARY FB RECOMMENDED WITH VIDEO MUTE BUTTON. THE MUTE ON/OFF WORKS
   DISCRETELY, BUT THE PROJECTOR WILL PUT THE PROJECTOR VIDEO MUTE ON/OFF
   SPORADICALLY WITH OTHER FUNCTIONS SUCH AS ZOOM, FOCUS, LENS SHIFT...*)
[TP,6] = [VPROJ,VP_VID_MUTE] && [VPROJ,VP_PWR]


                                   (************************)
                                   (* AUDIO                *)
                                   (************************)
PUSH[TP,7]                         (* VOL UP *)
{
  ON [VPROJ,VP_VOL_UP]
  OFF[VPROJ,VP_VOL_DN]
  OFF[VPROJ,VP_VOL_MUTE]
  SEND_STRING VPROJ,"'C09',13"
  CANCEL_WAIT 'VP ON DELAY'
  OFF[VPROJ,VP_ON_DELAY]
  OFF[VPROJ,VP_VID_MUTE]
  OFF[VPROJ,VP_NO_SHOW]
}
[TP,7] = [VPROJ,VP_VOL_UP]

PUSH[TP,8]                         (* VOL DOWN *)
{
  ON [VPROJ,VP_VOL_DN]
  OFF[VPROJ,VP_VOL_UP]
  OFF[VPROJ,VP_VOL_MUTE]
  SEND_STRING VPROJ,"'C0A',13"
  CANCEL_WAIT 'VP ON DELAY'
  OFF[VPROJ,VP_ON_DELAY]
  OFF[VPROJ,VP_VID_MUTE]
  OFF[VPROJ,VP_NO_SHOW]
}
[TP,8] = [VPROJ,VP_VOL_DN]

RELEASE[TP,7]
RELEASE[TP,8]
{
  OFF[VPROJ,VP_VOL_DN]
  OFF[VPROJ,VP_VOL_UP]
  CANCEL_WAIT 'VP VOL RAMP'
}

IF([VPROJ,VP_VOL_UP] || [VPROJ,VP_VOL_DN])  (* VOL RAMPING *)
{
  WAIT 1 'VP VOL RAMP'
  {
    SELECT
    {
      ACTIVE ([VPROJ,VP_VOL_UP]) : SEND_STRING VPROJ,"'C09',13"
      ACTIVE ([VPROJ,VP_VOL_DN]) : SEND_STRING VPROJ,"'C0A',13"
    }
  }
}

PUSH[TP,9]                         (* AUDIO MUTE *)
{
  IF(![VPROJ,VP_VOL_MUTE])
    CALL 'CANVP00F' (VP_VOL_MUTE)  (* AUDIO MUTE ON *)
  ELSE
    CALL 'CANVP00F' (VP_VOL_MUTE | $100)   (* AUDIO MUTE OFF *)
}
[TP,9] = [VPROJ,VP_VOL_MUTE] && [VPROJ,VP_PWR]


                                   (************************)
                                   (* ZOOM                 *)
                                   (************************)
PUSH[TP,10]                        (* ZOOM IN *)
{
  CALL 'CANVP00F' (VP_ZOOM_IN)
}
[TP,10] = [VPROJ,VP_ZOOM_IN]

PUSH[TP,11]                        (* ZOOM OUT *)
{
  CALL 'CANVP00F' (VP_ZOOM_OUT)
}
[TP,11] = [VPROJ,VP_ZOOM_OUT]

IF ([VPROJ,VP_ZOOM_IN] || [VPROJ,VP_ZOOM_OUT])
  ZOOM_COUNTER = ZOOM_COUNTER + 1

RELEASE[TP,10]
{
  CALL 'CANVP00F' (VP_ZOOM_IN | $100)
  ZOOM_COUNTER = 0
}
RELEASE[TP,11]
{
  CALL 'CANVP00F' (VP_ZOOM_OUT | $100)
  ZOOM_COUNTER = 0
}

IF([VPROJ,VP_ZOOM_IN] || [VPROJ,VP_ZOOM_OUT])     (* ZOOM RAMPING *)
{
  IF (ZOOM_COUNTER >= 40)          (* COUNTER CAUSES ZOOM SPEED TO *)
  {                                (* INCREASE AFTER 40 LOOPS      *)
    SELECT
    {
      ACTIVE ([VPROJ,VP_ZOOM_IN])  : CALL 'CANVP00F' (VP_ZOOM_IN)
      ACTIVE ([VPROJ,VP_ZOOM_OUT]) : CALL 'CANVP00F' (VP_ZOOM_OUT)
    }
  }
}

                                   (************************)
                                   (* FOCUS                *)
                                   (************************)
PUSH[TP,12]                        (* FOCUS NEAR *)
{
  CALL 'CANVP00F' (VP_FOCUS_NEAR)
}
[TP,12] = [VPROJ,VP_FOCUS_NEAR]

PUSH[TP,13]                        (* FOCUS FAR *)
{
  CALL 'CANVP00F' (VP_FOCUS_FAR)
}
[TP,13] = [VPROJ,VP_FOCUS_FAR]

RELEASE[TP,12]
{
  CALL 'CANVP00F' (VP_FOCUS_NEAR | $100)
  FOCUS_COUNTER = 0
}
RELEASE[TP,13]
{
  CALL 'CANVP00F' (VP_FOCUS_FAR | $100)
  FOCUS_COUNTER = 0
}

IF([VPROJ,VP_FOCUS_NEAR] || [VPROJ,VP_FOCUS_FAR])
   FOCUS_COUNTER = FOCUS_COUNTER + 1

IF([VPROJ,VP_FOCUS_NEAR] || [VPROJ,VP_FOCUS_FAR]) (* FOCUS RAMPING *)
{
  IF (FOCUS_COUNTER >= 40)         (* COUNTER CAUSES FOCUS SPEED TO *)
  {                                (* INCREASE AFTER 40 LOOPS       *)
    SELECT
    {
      ACTIVE ([VPROJ,VP_FOCUS_NEAR]) : CALL 'CANVP00F' (VP_FOCUS_NEAR)
      ACTIVE ([VPROJ,VP_FOCUS_FAR])  : CALL 'CANVP00F' (VP_FOCUS_FAR)
    }
  }
}

(* FIND.NOTES *)
(* NOTE:- THE DIGITAL ZOOM FUNCTION DOES NOT APPEAR TO DO ANYTHING WITH *)
(*      - THIS PROJECTOR, DESPITE ITS DESCRIPTION IN THE MANUAL. THE    *)
(*      - HAND CONTROL FOR THIS FUNCTION DOES NOT DO ANYTHING EITHER    *)

PUSH[TP,14]                        (* DIGITAL ZOOM *)
{
  SEND_STRING VPROJ,"'C88',13"
  TO[TP,14]
  CANCEL_WAIT 'VP ON DELAY'
  OFF[VPROJ,VP_ON_DELAY]
}

PUSH[TP,15]                        (* NO SHOW *)
{
  SEND_STRING VPROJ,"'C8B',13"
  CANCEL_WAIT 'VP ON DELAY'
  OFF[VPROJ,VP_ON_DELAY]
  OFF[VPROJ,VP_VID_MUTE]
  [VPROJ,VP_NO_SHOW] = ![VPROJ,VP_NO_SHOW]
}
[TP,15] = [VPROJ,VP_NO_SHOW]
                                   (************************)
                                   (* CURSOR               *)
                                   (************************)
PUSH[TP,16]                        (* CURSOR UP *)
{
  ON [VPROJ,VP_CURSOR_UP]
  OFF[VPROJ,VP_CURSOR_DN]
  OFF[VPROJ,VP_CURSOR_LT]
  OFF[VPROJ,VP_CURSOR_RT]
  SEND_STRING VPROJ,"'C3C',13"
}

PUSH[TP,17]                        (* CURSOR DOWN *)
{
  OFF[VPROJ,VP_CURSOR_UP]
  ON [VPROJ,VP_CURSOR_DN]
  OFF[VPROJ,VP_CURSOR_LT]
  OFF[VPROJ,VP_CURSOR_RT]
  SEND_STRING VPROJ,"'C3D',13"
}

PUSH[TP,18]                        (* CURSOR LEFT *)
{
  OFF[VPROJ,VP_CURSOR_UP]
  OFF[VPROJ,VP_CURSOR_DN]
  ON [VPROJ,VP_CURSOR_LT]
  OFF[VPROJ,VP_CURSOR_RT]
  SEND_STRING VPROJ,"'C3B',13"
}

PUSH[TP,19]                        (* CURSOR RIGHT *)
{
  OFF[VPROJ,VP_CURSOR_UP]
  OFF[VPROJ,VP_CURSOR_DN]
  OFF[VPROJ,VP_CURSOR_LT]
  ON [VPROJ,VP_CURSOR_RT]
  SEND_STRING VPROJ,"'C3A',13"
}

RELEASE[TP,16]
RELEASE[TP,17]
RELEASE[TP,18]
RELEASE[TP,19]
{
  OFF[VPROJ,VP_CURSOR_UP]
  OFF[VPROJ,VP_CURSOR_DN]
  OFF[VPROJ,VP_CURSOR_LT]
  OFF[VPROJ,VP_CURSOR_RT]
  CANCEL_WAIT 'VP CURSOR RAMP'
}
[TP,16] = [VPROJ,VP_CURSOR_UP]
[TP,17] = [VPROJ,VP_CURSOR_DN]
[TP,18] = [VPROJ,VP_CURSOR_LT]
[TP,19] = [VPROJ,VP_CURSOR_RT]

IF([VPROJ,VP_CURSOR_UP] || [VPROJ,VP_CURSOR_DN] ||      (* CURSOR RAMPING *)
   [VPROJ,VP_CURSOR_LT] || [VPROJ,VP_CURSOR_RT])
{
  WAIT 3 'VP CURSOR RAMP'
  {
    SELECT
    {
      ACTIVE ([VPROJ,VP_CURSOR_UP]) : SEND_STRING VPROJ,"'C3C',13"
      ACTIVE ([VPROJ,VP_CURSOR_DN]) : SEND_STRING VPROJ,"'C3D',13"
      ACTIVE ([VPROJ,VP_CURSOR_LT]) : SEND_STRING VPROJ,"'C3B',13"
      ACTIVE ([VPROJ,VP_CURSOR_RT]) : SEND_STRING VPROJ,"'C3A',13"
    }
  }
}

PUSH[TP,20]                        (* ENTER *)
{
  SEND_STRING VPROJ,"'C3F',13"
  TO[TP,20]
}

PUSH[TP,21]                        (* MENU ON *)
{
  TO [TP,21]
  ON [VPROJ,VP_MENU]
  SEND_STRING VPROJ,"'C1C',13"
  CANCEL_WAIT 'VP ON DELAY'
  OFF[VPROJ,VP_ON_DELAY]
  OFF[VPROJ,VP_VID_MUTE]
  OFF[VPROJ,VP_NO_SHOW]
}

PUSH[TP,22]                        (* MENU OFF *)
{
  TO [TP,22]
  OFF[VPROJ,VP_MENU]
  SEND_STRING VPROJ,"'C1D',13"
}

                                   (************************)
                                   (* MISC FUNCTIONS       *)
                                   (************************)
PUSH[TP,23]                        (* FREEZE *)
{
  TO [TP,23]
  ON [VPROJ,VP_FREEZE]
  SEND_STRING VPROJ,"'C43',13"
  CANCEL_WAIT 'VP ON DELAY'
  OFF[VPROJ,VP_ON_DELAY]
  OFF[VPROJ,VP_VID_MUTE]
  OFF[VPROJ,VP_NO_SHOW]
}

PUSH[TP,24]                        (* DISPLAY CLEAR *)
{
  SEND_STRING VPROJ,"'C1E',13"
  TO[TP,24]
  CANCEL_WAIT 'VP ON DELAY'
  OFF[VPROJ,VP_ON_DELAY]
  OFF[VPROJ,VP_VID_MUTE]
  OFF[VPROJ,VP_NO_SHOW]
}

PUSH[TP,25]                        (* NORMAL *)
{
  SEND_STRING VPROJ,"'C1F',13"
  TO[TP,25]
  CANCEL_WAIT 'VP ON DELAY'
  OFF[VPROJ,VP_ON_DELAY]
  OFF[VPROJ,VP_VID_MUTE]
  OFF[VPROJ,VP_NO_SHOW]
}


PUSH[TP,26]                        (* P-TIMER *)
{
  SEND_STRING VPROJ,"'C8A',13"
  TO[TP,26]
  CANCEL_WAIT 'VP ON DELAY'
  OFF[VPROJ,VP_ON_DELAY]
  OFF[VPROJ,VP_VID_MUTE]
  OFF[VPROJ,VP_NO_SHOW]
}

                                   (* FIND.NOTES *)
PUSH[TP,30]                        (* AUTO IMAGE *)
{                                  (* NOTE: PULLS DOWN AUTO IMAGE FROM MENU *)
  SEND_STRING VPROJ,"'C89',13"
  TO[TP,30]
  CANCEL_WAIT 'VP ON DELAY'
  OFF[VPROJ,VP_ON_DELAY]
  IF ([VPROJ,VP_PC1] || [VPROJ,VP_PC2])
  {
     OFF[VPROJ,VP_VID_MUTE]
     OFF[VPROJ,VP_NO_SHOW]
  }
}
                                   (************************)
                                   (* BUFFER PARSING       *)
                                   (************************)
(* FIND.NOTES *)
(* NOTE: - PROJECTOR SENDS "'2',6,13,10" FOR ANY CORRECTLY FORMATTED CMD.   *)
(*       - NO STATUS IS AVAILABLE.                                          *)
(*       - BUFFER PROCESSING IS ONLY GOOD WHEN DETERMINING WHETHER THE      *)
(*         PROJECTOR HAS STOPPED RESPONDING TO CMDS (LOCKED UP).            *)
RESPONSE = REMOVE_STRING(VPROJ_BUFF,"13,10",1)

IF(LENGTH_STRING(RESPONSE))
{
(*** DEBUG ***)
IF(DEBUG_VPROJ)
  SEND_STRING 0,"RESPONSE"

}

                                   (************************)
                                   (* MACROS               *)
                                   (************************)
(* FIND.NOTES *)
(* NOTE: - USE A 1/2 SECOND DELAY BETWEEN ON/INPUT CMDS AND INPUT/ON CMDS.  *)
PUSH[TP,250]                       (* MACRO = ON, VID1 SELECT *)
{
  CALL 'CANVP00F' (VP_ON)
  WAIT 5 'MACRO DELAY INPUT'
    CALL 'CANVP00F' (VP_VID1)
}


PUSH[TP,251]                       (* MACRO = PC2 SELECT, ON *)
{
  CALL 'CANVP00F' (VP_ON)
  WAIT 5 'MACRO DELAY ON'
    CALL 'CANVP00F' (VP_PC2)
}




(***********************************************************)
(*                     END OF PROGRAM                      *)
(*        DO NOT PUT ANY CODE BELOW THIS COMMENT           *)
(***********************************************************)

